<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Block\Adminhtml\Job;

use Neklo\Scheduler\Controller\Adminhtml\Job\Edit as EditCtrl;

class Edit extends \Magento\Backend\Block\Widget\Form\Container
{
    /**
     * @var \Magento\Framework\Registry
     */
    private $registry = null;

    /**
     * @param \Magento\Backend\Block\Widget\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Widget\Context $context,
        \Magento\Framework\Registry $registry,
        array $data = []
    ) {
        $this->registry = $registry;
        parent::__construct($context, $data);
    }

    /**
     * Initialize edit block
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_objectId = 'job_id';
        $this->_blockGroup = 'Neklo_Scheduler';
        $this->_controller = 'adminhtml_job';

        parent::_construct();

        if ($this->isAllowedAction('Neklo_Scheduler::edit')) {
            $this->buttonList->update('save', 'label', __('Save Job'));
            $this->buttonList->add(
                'saveandcontinue',
                [
                    'label' => __('Save and Continue Edit'),
                    'class' => 'save',
                    'data_attribute' => [
                        'mage-init' => [
                            'button' => [
                                'event' => 'saveAndContinueEdit',
                                'target' => '#edit_form'],
                        ],
                    ]
                ],
                -100
            );
            if ($this->getRequest()->getParam('id')) {
                $this->addButton(
                    'execute',
                    [
                        'label' => __('Run Now'),
                        'onclick' => 'deleteConfirm(' . json_encode(__('Are you sure you want to run this job?'))
                            . ','
                            . json_encode($this->getDeleteUrl())
                            . ')',
                        'class' => '',
                        'level' => -1
                    ]
                );
                $this->addButton(
                    'schedule',
                    [
                        'label' => __('Schedule Now'),
                        'onclick' => 'deleteConfirm(' . json_encode(__('Are you sure you want to schedule this job?'))
                            . ','
                            . json_encode($this->getScheduleUrl())
                            . ')',
                        'class' => '',
                        'level' => -2
                    ]
                );
            }
        } else {
            $this->buttonList->remove('save');
        }
    }

    /**
     * Retrieve text for header element depending on loaded page
     *
     * @return \Magento\Framework\Phrase
     */
    public function getHeaderText()
    {
        if ($this->registry->registry(EditCtrl::MODEL_REGISTRY)->getId()) {
            return __(
                "Edit Job: '%1'",
                $this->escapeHtml($this->registry->registry(EditCtrl::MODEL_REGISTRY)->getName())
            );
        } else {
            return __('New Job');
        }
    }

    /**
     * Check permission for passed action
     *
     * @param string $resourceId
     *
     * @return bool
     */
    private function isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }

    /**
     * Getter of url for "Save and Continue" button
     * tab_id will be replaced by desired by JS later
     *
     * @return string
     */
    protected function _getSaveAndContinueUrl()
    {
        return $this->getUrl('*/*/save', ['_current' => true, 'back' => 'edit']);
    }

    public function getDeleteUrl()
    {
        return $this->getUrl('*/*/execute', ['id' => $this->getRequest()->getParam('id')]);
    }

    public function getScheduleUrl()
    {
        return $this->getUrl('*/*/schedule', ['id' => $this->getRequest()->getParam('id')]);
    }
}
