<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Controller\Adminhtml\Job;

use Neklo\Scheduler\Controller\Adminhtml;
use Neklo\Scheduler\Api\Data\JobInterface;

class Execute extends Adminhtml\Action
{
    const ADMIN_RESOURCE = 'Neklo_Scheduler::edit';

    /**
     * Redirect url
     */
    const REDIRECT_URL = '*/job/index';

    /**
     *
     * @var \Neklo\Scheduler\Model\ScheduleFactory
     */
    private $scheduleFactory;

    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Neklo\Scheduler\Model\ScheduleFactory $scheduleFactory,
        \Magento\Framework\Registry $registry
    ) {
        parent::__construct($context, $resultPageFactory, $registry);
        $this->scheduleFactory = $scheduleFactory;
    }

    public function execute()
    {
        $id = $this->getRequest()->getParam(JobInterface::JOB_ID);
        $model = $this->_objectManager->create('Neklo\Scheduler\Model\Job');
        $errMsg = [];
        try {
            if ($id) {
                $model->load($id);
                if (!$model->getId()) {
                    $errMsg[] = __('This job ID(%1) no longer exists.', $id);
                } else {
                    $this->runIt($model);
                }
            }
        } catch (\Exception $e) {
            $errMsg[] = __($e->getMessage());
        }

        if (!empty($errMsg)) {
            $this->messageManager
                ->addError(implode('<br>', $errMsg));
        } else {
            $this->messageManager
                ->addSuccess(__('Job %1 updated', $model->getName()));
        }

        $resultRedirect = $this->resultRedirectFactory->create();
        return $resultRedirect->setPath(self::REDIRECT_URL);
    }

    private function runIt(\Neklo\Scheduler\Model\Job $item)
    {
        $key = $item->getName();

        $schedule = $this->scheduleFactory->create()
            ->initializeFromJob($item)
            ->setJob($item)
            ->setScheduledReason("Run From Admin");

        $schedule->runNow(false)->save();

        $messages = $schedule->getMessages();

        if (
            in_array(
                $schedule->getStatus(),
                [
                    \Neklo\Scheduler\Model\Schedule::STATUS_SUCCESS,
                    \Neklo\Scheduler\Model\Schedule::STATUS_DIDNTDOANYTHING
                ]
            )
        ) {
            $msgs = __('Ran %1 (Duration: %2 sec)', $key, intval($schedule->getDuration()));
            if ($messages) {
                $msgs .= '<br>' . __('%1 messages:<pre>%2</pre>', $key, $messages);
            }

            $this->messageManager->addSuccess($msgs);
        } else {
            $msgs = __('Error while running %1', $key);
            if ($messages) {
                $msgs .= '<br>' . __('%1 messages:<pre>%2</pre>', $key, $messages);
            }

            $this->messageManager->addError($msgs);
        }

        return $item;
    }
}
