<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Controller\Adminhtml\Job;

class MassExecute extends MassAbstract
{
    /**
     * @var \Neklo\Scheduler\Model\ScheduleFactory
     */
    private $scheduleFactory;

    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Framework\Registry $registry,
        \Neklo\Scheduler\Model\JobFactory $modelFactory,
        \Neklo\Scheduler\Model\ScheduleFactory $scheduleFactory,
        \Psr\Log\LoggerInterface $logger
    ) {
        $this->scheduleFactory = $scheduleFactory;
        parent::__construct(
            $context,
            $resultPageFactory,
            $registry,
            $modelFactory,
            $logger
        );
    }

    protected function itemOperation(\Neklo\Scheduler\Model\Job $item)
    {
        $key = $item->getName();

        $schedule = $this->scheduleFactory->create()
            ->initializeFromJob($item)
            ->setJob($item)
            ->setScheduledReason("Run From Admin");

        $schedule->runNow(false)->save();

        $messages = $schedule->getMessages();

        if (in_array(
            $schedule->getStatus(),
            [
                \Neklo\Scheduler\Model\Schedule::STATUS_SUCCESS,
                \Neklo\Scheduler\Model\Schedule::STATUS_DIDNTDOANYTHING
            ]
        )
        ) {
            $msgs = __('Ran %1 (Duration: %2 sec)', $key, (int)$schedule->getDuration());
            if ($messages) {
                $msgs .= '<br>'.__('%1 messages:<pre>%2</pre>', $key, $messages);
            }

            $this->messageManager->addSuccess($msgs);
        } else {
            $msgs = __('Error while running %1', $key);
            if ($messages) {
                $msgs .= '<br>'.__('%1 messages:<pre>%2</pre>', $key, $messages);
            }

            $this->messageManager->addError($msgs);
        }

        return $item;
    }
}
