<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Helper;

use Neklo\Scheduler\Model\Schedule;

class Process
{
    protected static $registry;

    /**
     * Configure process
     */
    public static function configure($registry)
    {
        static $configured = false;
        self::$registry = $registry;
        if (!$configured) {
            register_shutdown_function(['Neklo\Scheduler\Helper\Process', 'beforeDyingShutdown']);
            if (extension_loaded('pcntl')) {
                declare(ticks=1);
                pcntl_signal(SIGINT, ['Neklo\Scheduler\Helper\Process', 'beforeDyingSigint']); // CTRL + C
                pcntl_signal(SIGTERM, ['Neklo\Scheduler\Helper\Process', 'beforeDyingSigterm']); // kill <pid>
            }
            $configured = true;
        }
    }

    public static function beforeDying($message = null, $exit = false)
    {
        $schedule = self::$registry->registry('currently_running_schedule');
        /** @var $schedule \Neklo\Scheduler\Model\Schedule */
        if ($schedule !== null) {
            if ($message) {
                $schedule->addMessages($message);
            }

            $schedule
                ->setStatus(Schedule::STATUS_DIED)
                ->setFinishedAt(strftime('%Y-%m-%d %H:%M:%S', time()))
                ->save();
            self::$registry->unregister('currently_running_schedule');
        }

        if ($exit) {
            return;
        }
    }

    /**
     * Callback
     */
    public static function beforeDyingShutdown()
    {
        self::beforeDying('TRIGGER: shutdown function', false);
    }

    /**
     * Callback
     */
    public static function beforeDyingSigint()
    {
        self::beforeDying('TRIGGER: Signal SIGINT', true);
    }

    /**
     * Callback
     */
    public static function beforeDyingSigterm()
    {
        self::beforeDying('TRIGGER: Signal SIGTERM', true);
    }
}
